
package DefaultApp::GlobalASA;

use strict;
no warnings 'redefine';
use base 'Apache2::ASP::GlobalASA';
use vars qw($Request $Response $Session $Application $Server $Form);

1;# return true:
